<?php

namespace Drupal\delay_submit\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides autocomplete suggestions for form IDs.
 */
class FormAutocompleteController extends ControllerBase {

  /**
   * Handles form ID autocomplete.
   */
  public function handleAutocomplete(Request $request) {
    $input = $request->query->get('q');

    // Get dynamically detected forms.
    $form_ids = \Drupal::service('module_handler')->moduleExists('webform') ?
      \Drupal::service('entity_type.manager')->getStorage('webform')->loadMultiple() : [];

    $form_ids = array_map(function ($webform) {
      return 'webform_submission_' . $webform->id();
    }, $form_ids);

    $form_ids = array_merge($form_ids, [
      'user_login_form',
      'user_pass',
      'user_register_form',
      'contact_message_feedback_form',
    ]);

    $matches = array_filter($form_ids, function ($form_id) use ($input) {
      return stripos($form_id, $input) !== FALSE;
    });

    return new JsonResponse(array_values($matches));
  }
}
